/*
 * Copyright (C) 2021 Leah Rowe <leah@libreboot.org>
 *
 * Permission is granted to copy, distribute and/or modify this document
 * under the terms of the GNU Free Documentation License, Version 1.3
 * or any later version published by the Free Software Foundation;
 * with no Invariant Sections, no Front-Cover Texts, and no Back-Cover Texts.
 */

.warning_banner {
	background:#000000;
	color:#ffffff;
	margin:0 auto;
	font-family:sans-serif;
	line-height:5
}

html{
	background:#fff;
	color:#222;
}

table, th, td {
	border: solid;
	border-collapse: collapse;
}

.date,.author,.h a{display:none}
code,pre,#TOC,a:hover{background:#eee}
:not(p),a:hover {
	max-width:60em;
	margin:0 auto;
	font-family:sans-serif;
	line-height:1.4
}
a{color:#22d}
.title>*, header ul>li, .nav ul>li,
#footer ul>li, .h:hover>*
ul>li
{
	display:inline;
	margin:.7%;
	text-align:center;
}
.title>*,span.date{display:block}
img,video,iframe{max-width:100%}
#TOC{
	float:left;
	margin:1em
}
html,ul,#TOC{padding:1em}
@media (min-width:60em) {
	.title-logo{display:none}
	div.title {background-position:right}
	h1.title {padding:0 4em}
	#TOC{min-width:25%}
}
